@@ -42,6 +42,13 @@
 
 	$options = getopt("", $longopts);
 
+	if (!is_array($options)) {
+		die("error: getopt() failed. ".
+			"Most probably you are using PHP CGI to run this script ".
+			"instead of required PHP CLI. Check tt-rss wiki page on updating feeds for ".
+			"additional information.\n");
+	}
+
 	if (count($options) == 0 && !defined('STDIN')) {
 		?> <html>
 		<head>
